==> languagetool-3.8-1-any.pkg.tar.xz: usr/share/languagetool/org/languagetool/resource/es/etiquetas-eagles.md <==
# ETIQUETAS EAGLES (v. 2.0)

Los códigos ~~tachados~~ están sin implementar en LanguageTool.

## 1. ADJETIVOS

|Pos. | Atributo | Valor       | Código |
|-----|----------|-------------|:------:|
|1    |Categoría |Adjetivo     |   A    |
|2    |Tipo      |Calificativo |   Q    |
|	  |          |Ordinal      |   O    |
|3    |	Grado    |  ---        |   0    |
|     |          | Aumentativo | ~~A~~  |
|     |          | Diminutivo  | ~~D~~  |
|     |          | Comparativo | ~~C~~  |
|     |          | Superlativo | ~~S~~  |
|4    | Género   | Masculino   |   M    |
| 	  |          | Femenino    |   F    |
|     |          | Común       |   C    |
|5    | Número   | Singular    |   S    |
|     |          | Plural      |   P    |
|     |          | Invariable  |   N    |
|6    |Función   | ---         |   0    |
|     |          | Participio  |   P    |
	
## 2. ADVERBIOS

|Pos. | Atributo | Valor       | Código |
|-----|----------|-------------|:------:|
| 1   | Categoría| Adverbio    |   R    |
| 2   | Tipo     | General     |   G    |
| 	  |          | Negativo    |   N    |
		

## 3. DETERMINANTES

|Pos. | Atributo  | Valor         | Código |
|-----|-----------|---------------|:------:|
| 1   | Categoría | Determinante  |   D    |
| 2   | Tipo      | Demostrativo  |   D    |
| 	  |           | Posesivo      |   P    |
| 	  |           | Interrogativo |   T    |
| 	  |           | Exclamativo   |   E    |
| 	  |           | Indefinido    |   I    |
| 	  |           | Artículo      |   A    |
| 	  |           | Numeral       |   N    |
| 3   | Persona   | Primera       |   1    |
| 	  |           | Segunda       |   2    |
| 	  |           | Tercera       |   3    |
| 4   | Género    | Masculino     |   M    |
| 	  |           | Femenino      |   F    |
| 	  |           | Común         |   C    |
| 	  |           | Neutro        |   N    |
| 5   | Número    | Singular      |   S    |
| 	  |           | Plural        |   P    |
| 	  |           | Invariable    |   N    |
| 6   | Poseedor  | Singular      |   S    |
| 	  |           | Plural        |   P    |
			

## 4. NOMBRES

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Nombre      |   N    |
| 2   | Tipo          | Común       |   C    |
|     |               | Propio      |   P    |
| 3   | Género        | Masculino   |   M    |
|     |               | Femenino    |   F    |
| 	  |               | Común       |   C    |
| 4   | Número        | Singular    |   S    |
|     |               | Plural      |   P    |
|     |               | Invariable  |   N    |
| 5-6 | Clasificación | 
|     | semántica     | ---         |   00   |
|     |               | Persona     | ~~SP~~ |
|     |               | Lugar       | ~~G0~~ |
|     |               | Organización| ~~O0~~ |
|     |               | Otros       | ~~V0~~ |
| 7   | Grado         | Aumentativo | ~~A~~  |
|     |               | Diminutivo  | ~~D~~  |
|     |               | ---         |   0    |

## 5. VERBOS

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Verbo       |   V    |
| 2   | Tipo          | Principal   |   M    |
|     |               | Auxiliar    |   A    |
|     |               | Semiauxiliar|   S    |
| 3   | Modo          | Indicativo  |   I    |
|     |               | Subjuntivo  |   S    |
|     |               | Imperativo  |   M    |
|     |               | Infinitivo  |   N    |
|     |               | Gerundio    |   G    |
|     |               | Participio  |   P    |
| 4   | Tiempo        | Presente    |   P    |
|     |               | Imperfecto  |   I    |
|     |               | Futuro      |   F    |
|     |               | Pasado      |   S    |
|     |               | Condicional |   C    |
|     |               | ---         |   0    |
| 5   | Persona       | Primera     |   1    |
|     |               | Segunda     |   2    |
|     |               | Tercera     |   3    |
| 6   | Número        | Singular    |   S    |
|     |               | Plural      |   P    |
| 7   | Género        | Masculino   |   M    |
|     |               | Femenino    |   F    |

## 6. PRONOMBRES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Pronombre    |   P    |
| 2   | Tipo          | Personal     |   P    |
|     |               | Demostrativo |   D    |
|     |               | Posesivo     |   X    |
|     |               | Indefinido   |   I    |
|     |               | Interrogativo|   T    |
|     |               | Relativo     |   R    |
|     |               | Numeral      |   N    |
|     |               | Exclamativo  |   E    |
| 3   | Persona       | Primera      |   1    |
|     |               | Segunda      |   2    |
|     |               | Tercera      |   3    |
| 4   | Género        | Masculino    |   M    |
|     |               | Femenino     |   F    |
|     |               | Común        |   C    |
|     |               | Neutro       |   N    |
| 5   | Número        | Singular     |   S    |
|     |               | Plural       |   P    |
|     |               | Invariable   |   N    |
| 6   | Caso          | Nominativo   |   N    |
|     |               | Acusativo    |   A    |
| 	  |               | Dativo       |   D    |
|     |               | Oblicuo      |   O    |
| 7   | Poseedor      | Singular     |   S    |
|     |               | Plural       |   P    |
| 8   | Politeness    | Polite       | ~~P~~  |
|     |               | ---          |   0    |

## 7. CONJUNCIONES

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Conjunción  |   C    |
| 2   | Tipo          | Coordinada  |   C    |
|     |               | Subordinada |   S    |
			
## 8. INTERJECCIONES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Interjección |   I    |


## 9. PREPOSICIONES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Adposición   |   S    |
| 2   | Tipo          | Preposición  |   P    |
| 3   | Forma         | Simple       |   S    |
|     |               | Contraída    |   C    |
| 3   | Género        | Masculino    |   M    |
| 4   | Número        | Singular     |   S    |

## 10. SIGNOS DE PUNTUACIÓN

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Puntuación   | ~~F~~  |

## 11. CIFRAS

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Cifra        |   Z    |
| 2   | Tipo          | Moneda       | ~~m~~  |

## 12. FECHAS Y HORAS

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Fecha/Hora   | ~~W~~  |

==> languagetool-5.4-1-any.pkg.tar.xz: usr/share/languagetool/org/languagetool/resource/es/etiquetas-eagles.md <==
# ETIQUETAS EAGLES (v. 2.0)

Los códigos ~~tachados~~ están sin implementar en LanguageTool.

## 1. ADJETIVOS

|Pos. | Atributo | Valor       | Código |
|-----|----------|-------------|:------:|
|1    |Categoría |Adjetivo     |   A    |
|2    |Tipo      |Calificativo |   Q    |
|	  |          |Ordinal      |   O    |
|3    |	Grado    |  ---        |   0    |
|     |          | Aumentativo |   A    |
|     |          | Diminutivo  |   D    |
|     |          | Comparativo |   C    |
|     |          | Superlativo |   S    |
|4    | Género   | Masculino   |   M    |
| 	  |          | Femenino    |   F    |
|     |          | Común       |   C    |
|5    | Número   | Singular    |   S    |
|     |          | Plural      |   P    |
|     |          | Invariable  |   N    |
|6    |Función   | ---         |   0    |
|     |          | Participio  |   P    |
	
## 2. ADVERBIOS

|Pos. | Atributo | Valor       | Código |
|-----|----------|-------------|:------:|
| 1   | Categoría| Adverbio    |   R    |
| 2   | Tipo     | General     |   G    |
| 	  |          | Negativo    |   N    |
		

## 3. DETERMINANTES

|Pos. | Atributo  | Valor         | Código |
|-----|-----------|---------------|:------:|
| 1   | Categoría | Determinante  |   D    |
| 2   | Tipo      | Demostrativo  |   D    |
| 	  |           | Posesivo      |   P    |
| 	  |           | Interrogativo |   T    |
| 	  |           | Exclamativo   |   E    |
| 	  |           | Indefinido    |   I    |
| 	  |           | Artículo      |   A    |
| 	  |           | Numeral       |   N    |
| 3   | Persona   | Primera       |   1    |
| 	  |           | Segunda       |   2    |
| 	  |           | Tercera       |   3    |
| 4   | Género    | Masculino     |   M    |
| 	  |           | Femenino      |   F    |
| 	  |           | Común         |   C    |
| 	  |           | Neutro        |   N    |
| 5   | Número    | Singular      |   S    |
| 	  |           | Plural        |   P    |
| 	  |           | Invariable    |   N    |
| 6   | Poseedor  | Singular      |   S    |
| 	  |           | Plural        |   P    |
			

## 4. NOMBRES

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Nombre      |   N    |
| 2   | Tipo          | Común       |   C    |
|     |               | Propio      |   P    |
| 3   | Género        | Masculino   |   M    |
|     |               | Femenino    |   F    |
| 	  |               | Común       |   C    |
| 4   | Número        | Singular    |   S    |
|     |               | Plural      |   P    |
|     |               | Invariable  |   N    |
| 5-6 | Clasificación | 
|     | semántica     | ---         |   00   |
|     |               | Persona     | ~~SP~~ |
|     |               | Lugar       | ~~G0~~ |
|     |               | Organización| ~~O0~~ |
|     |               | Otros       | ~~V0~~ |
| 7   | Grado         | Aumentativo |   A    |
|     |               | Diminutivo  |   D    |
|     |               | ---         |   0    |

## 5. VERBOS

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Verbo       |   V    |
| 2   | Tipo          | Principal   |   M    |
|     |               | Auxiliar    |   A    |
|     |               | Semiauxiliar|   S    |
| 3   | Modo          | Indicativo  |   I    |
|     |               | Subjuntivo  |   S    |
|     |               | Imperativo  |   M    |
|     |               | Infinitivo  |   N    |
|     |               | Gerundio    |   G    |
|     |               | Participio  |   P    |
| 4   | Tiempo        | Presente    |   P    |
|     |               | Imperfecto  |   I    |
|     |               | Futuro      |   F    |
|     |               | Pasado      |   S    |
|     |               | Condicional |   C    |
|     |               | ---         |   0    |
| 5   | Persona       | Primera     |   1    |
|     |               | Segunda     |   2    |
|     |               | Tercera     |   3    |
| 6   | Número        | Singular    |   S    |
|     |               | Plural      |   P    |
| 7   | Género        | Masculino   |   M    |
|     |               | Femenino    |   F    |

## 6. PRONOMBRES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Pronombre    |   P    |
| 2   | Tipo          | Personal     |   P    |
|     |               | Demostrativo |   D    |
|     |               | Posesivo     |   X    |
|     |               | Indefinido   |   I    |
|     |               | Interrogativo|   T    |
|     |               | Relativo     |   R    |
|     |               | Numeral      |   N    |
|     |               | Exclamativo  |   E    |
| 3   | Persona       | Primera      |   1    |
|     |               | Segunda      |   2    |
|     |               | Tercera      |   3    |
| 4   | Género        | Masculino    |   M    |
|     |               | Femenino     |   F    |
|     |               | Común        |   C    |
|     |               | Neutro       |   N    |
| 5   | Número        | Singular     |   S    |
|     |               | Plural       |   P    |
|     |               | Invariable   |   N    |
| 6   | Caso          | Nominativo   |   N    |
|     |               | Acusativo    |   A    |
| 	  |               | Dativo       |   D    |
|     |               | Oblicuo      |   O    |
| 7   | Poseedor      | Singular     |   S    |
|     |               | Plural       |   P    |
| 8   | Politeness    | Polite       | ~~P~~  |
|     |               | ---          |   0    |

## 7. CONJUNCIONES

|Pos. | Atributo      | Valor       | Código |
|-----|---------------|-------------|:------:|
| 1   | Categoría     | Conjunción  |   C    |
| 2   | Tipo          | Coordinada  |   C    |
|     |               | Subordinada |   S    |
			
## 8. INTERJECCIONES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Interjección |   I    |


## 9. PREPOSICIONES

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Adposición   |   S    |
| 2   | Tipo          | Preposición  |   P    |
| 3   | Forma         | Simple       |   S    |
|     |               | Contraída    |   C    |
| 3   | Género        | Masculino    |   M    |
| 4   | Número        | Singular     |   S    |

## 10. SIGNOS DE PUNTUACIÓN

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Puntuación   | ~~F~~  |

## 11. CIFRAS

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Cifra        |   Z    |
| 2   | Tipo          | Moneda       | ~~m~~  |

## 12. FECHAS Y HORAS

|Pos. | Atributo      | Valor        | Código |
|-----|---------------|--------------|:------:|
| 1   | Categoría     | Fecha/Hora   | ~~W~~  |
